"""LCM package __init__.py file
This file automatically generated by lcm-gen.
DO NOT MODIFY BY HAND!!!!
lcm-gen 1.5.2
"""

from .lcmt_acrobot_u import lcmt_acrobot_u as lcmt_acrobot_u
from .lcmt_acrobot_x import lcmt_acrobot_x as lcmt_acrobot_x
from .lcmt_acrobot_y import lcmt_acrobot_y as lcmt_acrobot_y
from .lcmt_allegro_command import lcmt_allegro_command as lcmt_allegro_command
from .lcmt_allegro_status import lcmt_allegro_status as lcmt_allegro_status
from .lcmt_call_python import lcmt_call_python as lcmt_call_python
from .lcmt_call_python_data import lcmt_call_python_data as lcmt_call_python_data
from .lcmt_contact_results_for_viz import lcmt_contact_results_for_viz as lcmt_contact_results_for_viz
from .lcmt_drake_signal import lcmt_drake_signal as lcmt_drake_signal
from .lcmt_force_torque import lcmt_force_torque as lcmt_force_torque
from .lcmt_header import lcmt_header as lcmt_header
from .lcmt_hydroelastic_contact_surface_for_viz import lcmt_hydroelastic_contact_surface_for_viz as lcmt_hydroelastic_contact_surface_for_viz
from .lcmt_hydroelastic_quadrature_per_point_data_for_viz import lcmt_hydroelastic_quadrature_per_point_data_for_viz as lcmt_hydroelastic_quadrature_per_point_data_for_viz
from .lcmt_iiwa_command import lcmt_iiwa_command as lcmt_iiwa_command
from .lcmt_iiwa_status import lcmt_iiwa_status as lcmt_iiwa_status
from .lcmt_iiwa_status_telemetry import lcmt_iiwa_status_telemetry as lcmt_iiwa_status_telemetry
from .lcmt_image import lcmt_image as lcmt_image
from .lcmt_image_array import lcmt_image_array as lcmt_image_array
from .lcmt_jaco_command import lcmt_jaco_command as lcmt_jaco_command
from .lcmt_jaco_status import lcmt_jaco_status as lcmt_jaco_status
from .lcmt_panda_command import lcmt_panda_command as lcmt_panda_command
from .lcmt_panda_status import lcmt_panda_status as lcmt_panda_status
from .lcmt_planar_gripper_command import lcmt_planar_gripper_command as lcmt_planar_gripper_command
from .lcmt_planar_gripper_finger_command import lcmt_planar_gripper_finger_command as lcmt_planar_gripper_finger_command
from .lcmt_planar_gripper_finger_face_assignment import lcmt_planar_gripper_finger_face_assignment as lcmt_planar_gripper_finger_face_assignment
from .lcmt_planar_gripper_finger_face_assignments import lcmt_planar_gripper_finger_face_assignments as lcmt_planar_gripper_finger_face_assignments
from .lcmt_planar_gripper_finger_status import lcmt_planar_gripper_finger_status as lcmt_planar_gripper_finger_status
from .lcmt_planar_gripper_status import lcmt_planar_gripper_status as lcmt_planar_gripper_status
from .lcmt_planar_manipuland_status import lcmt_planar_manipuland_status as lcmt_planar_manipuland_status
from .lcmt_planar_plant_state import lcmt_planar_plant_state as lcmt_planar_plant_state
from .lcmt_point import lcmt_point as lcmt_point
from .lcmt_point_cloud import lcmt_point_cloud as lcmt_point_cloud
from .lcmt_point_cloud_field import lcmt_point_cloud_field as lcmt_point_cloud_field
from .lcmt_point_pair_contact_info_for_viz import lcmt_point_pair_contact_info_for_viz as lcmt_point_pair_contact_info_for_viz
from .lcmt_quaternion import lcmt_quaternion as lcmt_quaternion
from .lcmt_robot_plan import lcmt_robot_plan as lcmt_robot_plan
from .lcmt_robot_state import lcmt_robot_state as lcmt_robot_state
from .lcmt_schunk_wsg_command import lcmt_schunk_wsg_command as lcmt_schunk_wsg_command
from .lcmt_schunk_wsg_status import lcmt_schunk_wsg_status as lcmt_schunk_wsg_status
from .lcmt_scope import lcmt_scope as lcmt_scope
from .lcmt_viewer_command import lcmt_viewer_command as lcmt_viewer_command
from .lcmt_viewer_draw import lcmt_viewer_draw as lcmt_viewer_draw
from .lcmt_viewer_geometry_data import lcmt_viewer_geometry_data as lcmt_viewer_geometry_data
from .lcmt_viewer_link_data import lcmt_viewer_link_data as lcmt_viewer_link_data
from .lcmt_viewer_load_robot import lcmt_viewer_load_robot as lcmt_viewer_load_robot



"""Provides a roll-up of all user-visible modules and symbols in `pydrake`.

Things to note:

* The `.all` modules in `pydrake` are intended as convenient end-user shortcut
  for interactive or tutorial use. Please only use it for prototyping, but do
  not use it in production code.
* Code within pydrake itself should not use the all shortcut, but rather
  import only exactly what is needed.
* The downsides of importing an `.all` module are (a) pulling in additional
  dependencies, (b) the potential to lose a symbol if there is a conflict
  (e.g. something like `pydrake.multibody.shapes.Element` vs
  `pydrake.multibody.collision.Element` (which does not exist yet)), and
  (c) deprecated symbols could get removed without warning from `all` modules.
* Deprecated modules will *not* be incorporated in `all` modules, because
  otherwise, `all` would emit noisy deprecation warnings, or if they are
  suppressed, subseqeuent imports of those deprecated modules will not trigger
  warnings.
* Experimental modules are excluded from `all`.

To see example usages, please see `doc/python_bindings.rst`.

Note:
    Import order matters! If there is a name conflict, the last one imported
    wins. See "Preferred Ordering" section below.

**Preferred Ordering**: In service of maintaining convenient spellings, we have
a "preferred ordering" section in this top-level module. Please note that this
ordering is subject to change without notice. If you desire stability, please
**do not use** ``pydrake.all``. If you have a preferred ordering, please submit
a PR that will be subject to discussion and review. If you wish to debug
collisions, please run ``bazel run //bindings/pydrake:print_symbol_collision``
from the Drake source tree.
"""

# ruff: noqa: F401,F403 (unused-import, import-star)
# ruff: isort: skip_file

# Normal symbols.
from . import getDrakePath
from .autodiffutils import *
from .forwarddiff import *
from .lcm import *
from .manipulation import *
from .math import *
from .perception import *
from .planning import *
from .polynomial import *
from .solvers import *
from .symbolic import *
from .trajectories import *

# Submodules.
# - `.gym` is an optional dependency, so is excluded from `all`.
# - `.examples` does not offer public Drake library symbols.
from .common.all import *
from .geometry.all import *
from .multibody.all import *
from .systems.all import *
from .visualization import *

# Preferred Ordering. Please note this will *re*import some modules.
# - Ensure .math imports win over less capable .symbolic or .autodiffutils
# overloads.
from .math import *

# - Ensure symbolic.Polynomial wins over math.Polynomial (#18353).
from .symbolic import Polynomial

# Ensure that the command-line modules appear in the pydrake API reference.
import pydrake.visualization.meldis
import pydrake.visualization.model_visualizer

# Don't export submodule(s) named "experimental" (e.g., planning.experimental).
del experimental  # noqa: F821 (undefined-name)



import collections.abc
import enum
import nanobind
import pydrake.common
from typing import Any, Callable, ClassVar, overload

CalcMonomialBasisOrderUpToOne: nanobind.nb_func
CalcPolynomialWLowerTriangularPart: nanobind.nb_func
DecomposeAffineExpression: nanobind.nb_func
DecomposeAffineExpressions: nanobind.nb_func
DecomposeL2NormExpression: nanobind.nb_func
DecomposeLinearExpressions: nanobind.nb_func
DecomposeLumpedParameters: nanobind.nb_func
DecomposeQuadraticPolynomial: nanobind.nb_func
Evaluate: nanobind.nb_func
EvenDegreeMonomialBasis: nanobind.nb_func
ExtractVariablesFromExpression: nanobind.nb_func
GetVariableVector: nanobind.nb_func
IsAffine: nanobind.nb_func
Jacobian: nanobind.nb_func
MakeMatrixBinaryVariable: nanobind.nb_func
MakeMatrixBooleanVariable: nanobind.nb_func
MakeMatrixContinuousVariable: nanobind.nb_func
MakeMatrixVariable: nanobind.nb_func
MakeVectorBinaryVariable: nanobind.nb_func
MakeVectorBooleanVariable: nanobind.nb_func
MakeVectorContinuousVariable: nanobind.nb_func
MakeVectorVariable: nanobind.nb_func
MonomialBasis: nanobind.nb_func
OddDegreeMonomialBasis: nanobind.nb_func
ReplaceBilinearTerms: nanobind.nb_func
Substitute: nanobind.nb_func
SubstituteStereographicProjection: nanobind.nb_func
TaylorExpand: nanobind.nb_func
ToLatex: nanobind.nb_func
abs: nanobind.nb_func
acos: nanobind.nb_func
arccos: nanobind.nb_func
arcsin: nanobind.nb_func
arctan: nanobind.nb_func
arctan2: nanobind.nb_func
asin: nanobind.nb_func
atan: nanobind.nb_func
atan2: nanobind.nb_func
ceil: nanobind.nb_func
cos: nanobind.nb_func
cosh: nanobind.nb_func
exp: nanobind.nb_func
floor: nanobind.nb_func
forall: nanobind.nb_func
from_sympy: Callable
if_then_else: nanobind.nb_func
intersect: nanobind.nb_func
inv: nanobind.nb_func
isnan: nanobind.nb_func
log: nanobind.nb_func
logical_and: Callable
logical_not: nanobind.nb_func
logical_or: Callable
max: nanobind.nb_func
min: nanobind.nb_func
positive_semidefinite: nanobind.nb_func
pow: nanobind.nb_func
sin: nanobind.nb_func
sinh: nanobind.nb_func
sqrt: nanobind.nb_func
tan: nanobind.nb_func
tanh: nanobind.nb_func
to_sympy: Callable
uninterpreted_function: nanobind.nb_func

class Expression:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, constant: float) -> None: ...
    @overload
    def __init__(self, var: Variable) -> None: ...
    def Differentiate(self, x: Variable) -> Expression: ...
    def EqualTo(self, arg: Expression) -> bool: ...
    @overload
    def Evaluate(self, env: collections.abc.Mapping[Variable, float] = ..., generator: pydrake.common.RandomGenerator | None = ...) -> float: ...
    @overload
    def Evaluate(self, generator: pydrake.common.RandomGenerator | None) -> float: ...
    def EvaluatePartial(self, env: collections.abc.Mapping[Variable, float]) -> Expression: ...
    def Expand(self) -> Expression: ...
    def GetFreeVariables(self) -> Variables: ...
    def GetVariables(self) -> Variables: ...
    def Jacobian(self, *args, **kwargs): ...
    @overload
    def Substitute(self, var: Variable, e: Expression) -> Expression: ...
    @overload
    def Substitute(self, s: collections.abc.Mapping[Variable, Expression]) -> Expression: ...
    def Unapply(self) -> object: ...
    def abs(self) -> Expression: ...
    def acos(self) -> Expression: ...
    def arccos(self) -> Expression: ...
    def arcsin(self) -> Expression: ...
    def arctan(self) -> Expression: ...
    @overload
    def arctan2(self, x: Expression) -> Expression: ...
    @overload
    def arctan2(self, y, x) -> Any: ...
    def asin(self) -> Expression: ...
    def atan(self) -> Expression: ...
    @overload
    def atan2(self, x: Expression) -> Expression: ...
    @overload
    def atan2(self, y, x) -> Any: ...
    def ceil(self) -> Expression: ...
    def cos(self) -> Expression: ...
    def cosh(self) -> Expression: ...
    def exp(self) -> Expression: ...
    def floor(self) -> Expression: ...
    def get_kind(self) -> ExpressionKind: ...
    def is_polynomial(self) -> bool: ...
    def log(self) -> Expression: ...
    def max(self, arg: Expression) -> Expression: ...
    def min(self, arg: Expression) -> Expression: ...
    def pow(self, arg: float) -> Expression: ...
    def sin(self) -> Expression: ...
    def sinh(self) -> Expression: ...
    def sqrt(self) -> Expression: ...
    def tan(self) -> Expression: ...
    def tanh(self) -> Expression: ...
    def to_string(self) -> str: ...
    def __abs__(self) -> Expression: ...
    def __add__(self, arg: Expression) -> Expression: ...
    def __ceil__(self) -> Expression: ...
    @overload
    def __copy__(self) -> Expression: ...
    @overload
    def __copy__(self) -> Expression: ...
    def __deepcopy__(self, arg: dict) -> Expression: ...
    def __eq__(self, arg: Expression) -> Formula: ...
    def __floor__(self) -> Expression: ...
    def __ge__(self, arg: Expression) -> Formula: ...
    def __gt__(self, arg: Expression) -> Formula: ...
    def __iadd__(self, arg: Expression) -> Expression: ...
    def __imul__(self, arg: Expression) -> Expression: ...
    def __isub__(self, arg: Expression) -> Expression: ...
    def __itruediv__(self, arg: Expression) -> Expression: ...
    def __le__(self, arg: Expression) -> Formula: ...
    def __lt__(self, arg: Expression) -> Formula: ...
    def __mul__(self, arg: Expression) -> Expression: ...
    def __ne__(self, arg: Expression) -> Formula: ...
    def __neg__(self) -> Expression: ...
    def __pos__(self) -> Expression: ...
    def __pow__(self, arg: float) -> Expression: ...
    def __radd__(self, arg: Variable) -> Expression: ...
    def __rmul__(self, arg: Variable) -> Expression: ...
    def __rsub__(self, arg: Variable) -> Expression: ...
    def __rtruediv__(self, arg: Variable) -> Expression: ...
    def __sub__(self, arg: Expression) -> Expression: ...
    def __truediv__(self, arg: Expression) -> Expression: ...

class ExpressionKind(enum.Enum):
    __new__: ClassVar[Callable] = ...
    Abs: ClassVar[ExpressionKind] = ...
    Acos: ClassVar[ExpressionKind] = ...
    Add: ClassVar[ExpressionKind] = ...
    Asin: ClassVar[ExpressionKind] = ...
    Atan: ClassVar[ExpressionKind] = ...
    Atan2: ClassVar[ExpressionKind] = ...
    Ceil: ClassVar[ExpressionKind] = ...
    Constant: ClassVar[ExpressionKind] = ...
    Cos: ClassVar[ExpressionKind] = ...
    Cosh: ClassVar[ExpressionKind] = ...
    Div: ClassVar[ExpressionKind] = ...
    Exp: ClassVar[ExpressionKind] = ...
    Floor: ClassVar[ExpressionKind] = ...
    IfThenElse: ClassVar[ExpressionKind] = ...
    Log: ClassVar[ExpressionKind] = ...
    Max: ClassVar[ExpressionKind] = ...
    Min: ClassVar[ExpressionKind] = ...
    Mul: ClassVar[ExpressionKind] = ...
    NaN: ClassVar[ExpressionKind] = ...
    Pow: ClassVar[ExpressionKind] = ...
    Sin: ClassVar[ExpressionKind] = ...
    Sinh: ClassVar[ExpressionKind] = ...
    Sqrt: ClassVar[ExpressionKind] = ...
    Tan: ClassVar[ExpressionKind] = ...
    Tanh: ClassVar[ExpressionKind] = ...
    UninterpretedFunction: ClassVar[ExpressionKind] = ...
    Var: ClassVar[ExpressionKind] = ...
    _generate_next_value_: ClassVar[Callable] = ...
    _hashable_values_: ClassVar[list] = ...
    _member_map_: ClassVar[dict] = ...
    _member_names_: ClassVar[list] = ...
    _member_type_: ClassVar[type[object]] = ...
    _unhashable_values_: ClassVar[list] = ...
    _unhashable_values_map_: ClassVar[dict] = ...
    _use_args_: ClassVar[bool] = ...
    _value2member_map_: ClassVar[dict] = ...
    _value_repr_: ClassVar[None] = ...
    __nb_enum__: ClassVar[PyCapsule] = ...

class Formula:
    False_: ClassVar[nanobind.nb_func] = ...
    True_: ClassVar[nanobind.nb_func] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, value: bool) -> None: ...
    @overload
    def __init__(self, var: Variable) -> None: ...
    def EqualTo(self, arg: Formula) -> bool: ...
    def Evaluate(self, env: collections.abc.Mapping[Variable, float] = ...) -> bool: ...
    def GetFreeVariables(self) -> Variables: ...
    @overload
    def Substitute(self, var: Variable, e: Expression) -> Formula: ...
    @overload
    def Substitute(self, var: Variable, e: Variable) -> Formula: ...
    @overload
    def Substitute(self, var: Variable, e: float) -> Formula: ...
    @overload
    def Substitute(self, s: collections.abc.Mapping[Variable, Expression]) -> Formula: ...
    def Unapply(self) -> object: ...
    def get_kind(self) -> FormulaKind: ...
    def to_string(self) -> str: ...
    def __bool__(self) -> bool: ...
    def __eq__(self, arg: Formula) -> bool: ...
    def __hash__(self) -> int: ...
    def __ne__(self, arg: Formula) -> bool: ...
    def __nonzero__(self) -> None: ...

class FormulaKind(enum.Enum):
    __new__: ClassVar[Callable] = ...
    And: ClassVar[FormulaKind] = ...
    Eq: ClassVar[FormulaKind] = ...
    False_: ClassVar[FormulaKind] = ...
    Forall: ClassVar[FormulaKind] = ...
    Geq: ClassVar[FormulaKind] = ...
    Gt: ClassVar[FormulaKind] = ...
    Isnan: ClassVar[FormulaKind] = ...
    Leq: ClassVar[FormulaKind] = ...
    Lt: ClassVar[FormulaKind] = ...
    Neq: ClassVar[FormulaKind] = ...
    Not: ClassVar[FormulaKind] = ...
    Or: ClassVar[FormulaKind] = ...
    PositiveSemidefinite: ClassVar[FormulaKind] = ...
    True_: ClassVar[FormulaKind] = ...
    Var: ClassVar[FormulaKind] = ...
    _generate_next_value_: ClassVar[Callable] = ...
    _hashable_values_: ClassVar[list] = ...
    _member_map_: ClassVar[dict] = ...
    _member_names_: ClassVar[list] = ...
    _member_type_: ClassVar[type[object]] = ...
    _unhashable_values_: ClassVar[list] = ...
    _unhashable_values_map_: ClassVar[dict] = ...
    _use_args_: ClassVar[bool] = ...
    _value2member_map_: ClassVar[dict] = ...
    _value_repr_: ClassVar[None] = ...
    __nb_enum__: ClassVar[PyCapsule] = ...

class Monomial:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, var: Variable) -> None: ...
    @overload
    def __init__(self, var: Variable, exponent: int) -> None: ...
    @overload
    def __init__(self, powers: collections.abc.Mapping[Variable, int]) -> None: ...
    @overload
    def __init__(self, vars, exponents) -> None: ...
    def EqualTo(self, arg: Monomial) -> bool: ...
    def Evaluate(self, env: collections.abc.Mapping[Variable, float]) -> float: ...
    def EvaluatePartial(self, env: collections.abc.Mapping[Variable, float]) -> tuple[float, Monomial]: ...
    def GetVariables(self) -> Variables: ...
    def ToExpression(self) -> Expression: ...
    def degree(self, v: Variable) -> int: ...
    def get_powers(self) -> dict[Variable, int]: ...
    def pow_in_place(self, p: int) -> Monomial: ...
    def total_degree(self) -> int: ...
    def __add__(self, arg: Expression) -> Expression: ...
    def __eq__(self, arg: Monomial) -> bool: ...
    def __hash__(self) -> int: ...
    def __imul__(self, arg: Monomial) -> Monomial: ...
    def __mul__(self, arg: Monomial) -> Monomial: ...
    def __ne__(self, arg: Monomial) -> bool: ...
    def __pow__(self, arg: int) -> Monomial: ...
    def __radd__(self, arg: Expression) -> Expression: ...
    def __rmul__(self, arg: float) -> Polynomial: ...
    def __rsub__(self, arg: Expression) -> Expression: ...
    def __rtruediv__(self, arg: Expression) -> Expression: ...
    def __sub__(self, arg: Expression) -> Expression: ...
    def __truediv__(self, arg: Expression) -> Expression: ...

class Polynomial:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, map: collections.abc.Mapping[Monomial, Expression]) -> None: ...
    @overload
    def __init__(self, m: Monomial) -> None: ...
    @overload
    def __init__(self, e: Expression) -> None: ...
    @overload
    def __init__(self, e: Expression, indeterminates: Variables) -> None: ...
    @overload
    def __init__(self, e: Expression, indeterminates) -> None: ...
    def AddProduct(self, coeff: Expression, m: Monomial) -> Polynomial: ...
    def CoefficientsAlmostEqual(self, p: Polynomial, tolerance: float) -> bool: ...
    def Degree(self, v: Variable) -> int: ...
    def Differentiate(self, x: Variable) -> Polynomial: ...
    def EqualTo(self, arg: Polynomial) -> bool: ...
    def Evaluate(self, env: collections.abc.Mapping[Variable, float]) -> float: ...
    def EvaluateIndeterminates(self, *args, **kwargs): ...
    @overload
    def EvaluatePartial(self, env: collections.abc.Mapping[Variable, float]) -> Polynomial: ...
    @overload
    def EvaluatePartial(self, var: Variable, c: float) -> Polynomial: ...
    def EvaluateWithAffineCoefficients(self, *args, **kwargs): ...
    def Expand(self) -> Polynomial: ...
    @overload
    def Integrate(self, x: Variable) -> Polynomial: ...
    @overload
    def Integrate(self, x: Variable, a: float, b: float) -> Polynomial: ...
    def IsEven(self) -> bool: ...
    def IsOdd(self) -> bool: ...
    def Jacobian(self, *args, **kwargs): ...
    def RemoveTermsWithSmallCoefficients(self, coefficient_tol: float) -> Polynomial: ...
    def Roots(self, *args, **kwargs): ...
    def SetIndeterminates(self, new_indeterminates: Variables) -> None: ...
    def SubstituteAndExpand(self, indeterminate_substitution: collections.abc.Mapping[Variable, Polynomial], substitutions_cached_data: SubstituteAndExpandCacheData | None = ...) -> Polynomial: ...
    def ToExpression(self) -> Expression: ...
    def TotalDegree(self) -> int: ...
    def decision_variables(self) -> Variables: ...
    def indeterminates(self) -> Variables: ...
    @overload
    def monomial_to_coefficient_map(self) -> dict[Monomial, Expression]: ...
    @overload
    def monomial_to_coefficient_map(self) -> Any: ...
    def __add__(self, arg: Polynomial) -> Polynomial: ...
    def __eq__(self, arg: Polynomial) -> Formula: ...
    def __hash__(self) -> int: ...
    def __mul__(self, arg: Polynomial) -> Polynomial: ...
    def __ne__(self, arg: Polynomial) -> Formula: ...
    def __neg__(self) -> Polynomial: ...
    def __pow__(self, arg: int) -> Polynomial: ...
    def __radd__(self, arg: Monomial) -> Polynomial: ...
    def __rmul__(self, arg: Monomial) -> Polynomial: ...
    def __rsub__(self, arg: Monomial) -> Polynomial: ...
    def __rtruediv__(self, arg: float) -> Expression: ...
    def __sub__(self, arg: Polynomial) -> Polynomial: ...
    def __truediv__(self, arg: float) -> Polynomial: ...

class RationalFunction:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, numerator: Polynomial, denominator: Polynomial) -> None: ...
    @overload
    def __init__(self, p: Polynomial) -> None: ...
    @overload
    def __init__(self, m: Monomial) -> None: ...
    @overload
    def __init__(self, c: float) -> None: ...
    @overload
    def __init__(self) -> None: ...
    def EqualTo(self, f: RationalFunction) -> bool: ...
    def Evaluate(self, env: collections.abc.Mapping[Variable, float]) -> float: ...
    def SetIndeterminates(self, new_indeterminates: Variables) -> None: ...
    def ToExpression(self) -> Expression: ...
    def denominator(self) -> Polynomial: ...
    def numerator(self) -> Polynomial: ...
    def __add__(self, arg: RationalFunction) -> RationalFunction: ...
    def __eq__(self, arg: RationalFunction) -> Formula: ...
    def __mul__(self, arg: RationalFunction) -> RationalFunction: ...
    def __ne__(self, arg: RationalFunction) -> Formula: ...
    def __neg__(self) -> RationalFunction: ...
    def __radd__(self, arg: float) -> RationalFunction: ...
    def __rmul__(self, arg: float) -> RationalFunction: ...
    def __rsub__(self, arg: float) -> RationalFunction: ...
    def __rtruediv__(self, arg: float) -> RationalFunction: ...
    def __sub__(self, arg: RationalFunction) -> RationalFunction: ...
    def __truediv__(self, arg: RationalFunction) -> RationalFunction: ...

class SinCos:
    c: Variable
    s: Variable
    type: SinCosSubstitutionType
    def __init__(self, s: Variable, c: Variable, type: SinCosSubstitutionType = ...) -> None: ...

class SinCosSubstitutionType(enum.Enum):
    __new__: ClassVar[Callable] = ...
    _generate_next_value_: ClassVar[Callable] = ...
    _hashable_values_: ClassVar[list] = ...
    _member_map_: ClassVar[dict] = ...
    _member_names_: ClassVar[list] = ...
    _member_type_: ClassVar[type[object]] = ...
    _unhashable_values_: ClassVar[list] = ...
    _unhashable_values_map_: ClassVar[dict] = ...
    _use_args_: ClassVar[bool] = ...
    _value2member_map_: ClassVar[dict] = ...
    _value_repr_: ClassVar[None] = ...
    kAngle: ClassVar[SinCosSubstitutionType] = ...
    kHalfAnglePreferCos: ClassVar[SinCosSubstitutionType] = ...
    kHalfAnglePreferSin: ClassVar[SinCosSubstitutionType] = ...
    __nb_enum__: ClassVar[PyCapsule] = ...

class SubstituteAndExpandCacheData:
    def __init__(self) -> None: ...
    def get_data(self) -> dict[Monomial, Polynomial]: ...

class Variable:
    class Type(enum.Enum):
        __new__: ClassVar[Callable] = ...
        BINARY: ClassVar[Variable.Type] = ...
        BOOLEAN: ClassVar[Variable.Type] = ...
        CONTINUOUS: ClassVar[Variable.Type] = ...
        INTEGER: ClassVar[Variable.Type] = ...
        RANDOM_EXPONENTIAL: ClassVar[Variable.Type] = ...
        RANDOM_GAUSSIAN: ClassVar[Variable.Type] = ...
        RANDOM_UNIFORM: ClassVar[Variable.Type] = ...
        _generate_next_value_: ClassVar[Callable] = ...
        _hashable_values_: ClassVar[list] = ...
        _member_map_: ClassVar[dict] = ...
        _member_names_: ClassVar[list] = ...
        _member_type_: ClassVar[type[object]] = ...
        _unhashable_values_: ClassVar[list] = ...
        _unhashable_values_map_: ClassVar[dict] = ...
        _use_args_: ClassVar[bool] = ...
        _value2member_map_: ClassVar[dict] = ...
        _value_repr_: ClassVar[None] = ...
        __nb_enum__: ClassVar[PyCapsule] = ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, name: str, type: Variable.Type = ...) -> None: ...
    def EqualTo(self, arg: Variable) -> bool: ...
    def abs(self) -> Expression: ...
    def acos(self) -> Expression: ...
    def arccos(self) -> Expression: ...
    def arcsin(self) -> Expression: ...
    def arctan(self) -> Expression: ...
    @overload
    def arctan2(self, x: Variable) -> Expression: ...
    @overload
    def arctan2(self, y, x) -> Any: ...
    def asin(self) -> Expression: ...
    def atan(self) -> Expression: ...
    @overload
    def atan2(self, x: Variable) -> Expression: ...
    @overload
    def atan2(self, y, x) -> Any: ...
    def ceil(self) -> Expression: ...
    def cos(self) -> Expression: ...
    def cosh(self) -> Expression: ...
    def exp(self) -> Expression: ...
    def floor(self) -> Expression: ...
    def get_id(self) -> int: ...
    def get_name(self) -> str: ...
    def get_type(self) -> Variable.Type: ...
    def is_dummy(self) -> bool: ...
    def log(self) -> Expression: ...
    def max(self, arg: Variable) -> Expression: ...
    def min(self, arg: Variable) -> Expression: ...
    def pow(self, arg: float) -> Expression: ...
    def sin(self) -> Expression: ...
    def sinh(self) -> Expression: ...
    def sqrt(self) -> Expression: ...
    def tan(self) -> Expression: ...
    def tanh(self) -> Expression: ...
    def __abs__(self) -> Expression: ...
    def __add__(self, arg: Variable) -> Expression: ...
    def __ceil__(self) -> Expression: ...
    def __copy__(self) -> Variable: ...
    def __deepcopy__(self, arg: dict) -> Variable: ...
    def __eq__(self, arg: Expression) -> Formula: ...
    def __floor__(self) -> Expression: ...
    def __ge__(self, arg: Expression) -> Formula: ...
    def __gt__(self, arg: Expression) -> Formula: ...
    def __hash__(self) -> int: ...
    def __le__(self, arg: Expression) -> Formula: ...
    def __lt__(self, arg: Expression) -> Formula: ...
    def __mul__(self, arg: Variable) -> Expression: ...
    def __ne__(self, arg: Expression) -> Formula: ...
    def __neg__(self) -> Expression: ...
    def __pos__(self) -> Expression: ...
    def __pow__(self, arg: float) -> Expression: ...
    def __radd__(self, arg: float) -> Expression: ...
    def __rmul__(self, arg: float) -> Expression: ...
    def __rsub__(self, arg: float) -> Expression: ...
    def __rtruediv__(self, arg: float) -> Expression: ...
    def __sub__(self, arg: Variable) -> Expression: ...
    def __truediv__(self, arg: Variable) -> Expression: ...

class Variables:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg) -> None: ...
    def EqualTo(self, arg: Variables) -> bool: ...
    def IsStrictSubsetOf(self, vars: Variables) -> bool: ...
    def IsStrictSupersetOf(self, vars: Variables) -> bool: ...
    def IsSubsetOf(self, vars: Variables) -> bool: ...
    def IsSupersetOf(self, vars: Variables) -> bool: ...
    def empty(self) -> bool: ...
    @overload
    def erase(self, key: Variable) -> int: ...
    @overload
    def erase(self, vars: Variables) -> int: ...
    def include(self, key: Variable) -> bool: ...
    @overload
    def insert(self, var: Variable) -> None: ...
    @overload
    def insert(self, vars: Variables) -> None: ...
    def size(self) -> int: ...
    def to_string(self) -> str: ...
    def __add__(self, arg: Variables) -> Variables: ...
    def __contains__(self, arg: Variable) -> bool: ...
    def __eq__(self, arg: Variables) -> bool: ...
    def __hash__(self) -> int: ...
    def __iter__(self) -> collections.abc.Iterator[Variable]: ...
    def __len__(self) -> int: ...
    def __lt__(self, arg: Variables) -> bool: ...
    def __radd__(self, arg: Variable) -> Variables: ...
    def __sub__(self, arg: Variables) -> Variables: ...



import collections.abc
import enum
import nanobind
import pydrake.common.eigen_geometry
import pydrake.geometry
import pydrake.math
import pydrake.multibody.math
import pydrake.multibody.plant
import pydrake.multibody.tree
import pydrake.planning
import pydrake.solvers
import pydrake.systems.framework
from _typeshed import Incomplete
from typing import Callable, ClassVar, overload

AddMultibodyPlantConstraints: nanobind.nb_func
AddUnitQuaternionConstraintOnPlant: nanobind.nb_func
DoDifferentialInverseKinematics: nanobind.nb_func

class AngleBetweenVectorsConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frameA: pydrake.multibody.tree.Frame, a_A, frameB: pydrake.multibody.tree.Frame, b_B, angle_lower: float, angle_upper: float, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frameA: pydrake.multibody.tree.Frame_TAutoDiffXdU, a_A, frameB: pydrake.multibody.tree.Frame_TAutoDiffXdU, b_B, angle_lower: float, angle_upper: float, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class AngleBetweenVectorsCost(pydrake.solvers.Cost):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frameA: pydrake.multibody.tree.Frame, a_A, frameB: pydrake.multibody.tree.Frame, b_B, c: float, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frameA: pydrake.multibody.tree.Frame_TAutoDiffXdU, a_A, frameB: pydrake.multibody.tree.Frame_TAutoDiffXdU, b_B, c: float, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class ComInPolyhedronConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, model_instances: collections.abc.Sequence[pydrake.multibody.tree.ModelInstanceIndex] | None, expressed_frame: pydrake.multibody.tree.Frame, A, lb, ub, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, model_instances: collections.abc.Sequence[pydrake.multibody.tree.ModelInstanceIndex] | None, expressed_frame: pydrake.multibody.tree.Frame_TAutoDiffXdU, A, lb, ub, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class ComPositionConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, model_instances: collections.abc.Sequence[pydrake.multibody.tree.ModelInstanceIndex] | None, expressed_frame: pydrake.multibody.tree.Frame, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, model_instances: collections.abc.Sequence[pydrake.multibody.tree.ModelInstanceIndex] | None, expressed_frame: pydrake.multibody.tree.Frame_TAutoDiffXdU, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class DifferentialInverseKinematicsController(pydrake.systems.framework.Diagram):
    def __init__(self, differential_inverse_kinematics: object, planar_rotation_dof_indices: collections.abc.Sequence[int]) -> None: ...
    def differential_inverse_kinematics(self) -> DifferentialInverseKinematicsSystem: ...
    def get_mutable_differential_inverse_kinematics(self) -> DifferentialInverseKinematicsSystem: ...
    def set_initial_position(self, context: pydrake.systems.framework.Context, value) -> None: ...

class DifferentialInverseKinematicsIntegrator(pydrake.systems.framework.LeafSystem):
    @overload
    def __init__(self, robot: pydrake.multibody.plant.MultibodyPlant, frame_A: pydrake.multibody.tree.Frame, frame_E: pydrake.multibody.tree.Frame, time_step: float, parameters: DifferentialInverseKinematicsParameters, robot_context: pydrake.systems.framework.Context | None = ..., log_only_when_result_state_changes: bool = ...) -> None: ...
    @overload
    def __init__(self, robot: pydrake.multibody.plant.MultibodyPlant, frame_E: pydrake.multibody.tree.Frame, time_step: float, parameters: DifferentialInverseKinematicsParameters, robot_context: pydrake.systems.framework.Context | None = ..., log_only_when_result_state_changes: bool = ...) -> None: ...
    def ForwardKinematics(self, context: pydrake.systems.framework.Context) -> pydrake.math.RigidTransform: ...
    def SetPositions(self, context: pydrake.systems.framework.Context, positions) -> None: ...
    def get_mutable_parameters(self) -> DifferentialInverseKinematicsParameters: ...
    def get_parameters(self) -> DifferentialInverseKinematicsParameters: ...

class DifferentialInverseKinematicsParameters:
    def __init__(self, num_positions: int, num_velocities: int | None = ...) -> None: ...
    def get_end_effector_angular_speed_limit(self) -> float: ...
    def get_end_effector_translational_velocity_limits(self, *args, **kwargs): ...
    def get_end_effector_velocity_flag(self, *args, **kwargs): ...
    def get_joint_acceleration_limits(self, *args, **kwargs): ...
    def get_joint_centering_gain(self, *args, **kwargs): ...
    def get_joint_position_limits(self, *args, **kwargs): ...
    def get_joint_velocity_limits(self, *args, **kwargs): ...
    def get_maximum_scaling_to_report_stuck(self) -> float: ...
    def get_mutable_solver_options(self) -> pydrake.solvers.SolverOptions: ...
    def get_nominal_joint_position(self, *args, **kwargs): ...
    def get_num_positions(self) -> int: ...
    def get_num_velocities(self) -> int: ...
    def get_time_step(self) -> float: ...
    def set_end_effector_angular_speed_limit(self, speed: float) -> None: ...
    def set_end_effector_translational_velocity_limits(self, lower, upper) -> None: ...
    def set_end_effector_velocity_flag(self, flag_E) -> None: ...
    def set_joint_acceleration_limits(self, arg) -> None: ...
    def set_joint_centering_gain(self, K) -> None: ...
    def set_joint_position_limits(self, arg) -> None: ...
    def set_joint_velocity_limits(self, arg) -> None: ...
    def set_maximum_scaling_to_report_stuck(self, scaling: float) -> None: ...
    def set_nominal_joint_position(self, arg) -> None: ...
    def set_time_step(self, dt: float) -> None: ...

class DifferentialInverseKinematicsResult:
    joint_velocities: Incomplete
    status: Incomplete
    def __init__(self, **kwargs) -> None: ...

class DifferentialInverseKinematicsStatus(enum.Enum):
    __new__: ClassVar[Callable] = ...
    _generate_next_value_: ClassVar[Callable] = ...
    _hashable_values_: ClassVar[list] = ...
    _member_map_: ClassVar[dict] = ...
    _member_names_: ClassVar[list] = ...
    _member_type_: ClassVar[type[object]] = ...
    _unhashable_values_: ClassVar[list] = ...
    _unhashable_values_map_: ClassVar[dict] = ...
    _use_args_: ClassVar[bool] = ...
    _value2member_map_: ClassVar[dict] = ...
    _value_repr_: ClassVar[None] = ...
    kNoSolutionFound: ClassVar[DifferentialInverseKinematicsStatus] = ...
    kSolutionFound: ClassVar[DifferentialInverseKinematicsStatus] = ...
    kStuck: ClassVar[DifferentialInverseKinematicsStatus] = ...
    __nb_enum__: ClassVar[PyCapsule] = ...

class DifferentialInverseKinematicsSystem(pydrake.systems.framework.LeafSystem):
    class CartesianPositionLimitConstraint(DifferentialInverseKinematicsSystem.Ingredient):
        class Config:
            p_TG_next_lower: Incomplete
            p_TG_next_upper: Incomplete
            def __init__(self, **kwargs) -> None: ...
            def __copy__(self) -> DifferentialInverseKinematicsSystem.CartesianPositionLimitConstraint.Config: ...
            def __deepcopy__(self, arg: dict) -> DifferentialInverseKinematicsSystem.CartesianPositionLimitConstraint.Config: ...
            @property
            def __fields__(self): ...
        def __init__(self, config: DifferentialInverseKinematicsSystem.CartesianPositionLimitConstraint.Config) -> None: ...
        def GetConfig(self) -> DifferentialInverseKinematicsSystem.CartesianPositionLimitConstraint.Config: ...
        def SetConfig(self, config: DifferentialInverseKinematicsSystem.CartesianPositionLimitConstraint.Config) -> None: ...

    class CartesianVelocityLimitConstraint(DifferentialInverseKinematicsSystem.Ingredient):
        class Config:
            V_next_TG_limit: Incomplete
            def __init__(self, **kwargs) -> None: ...
            def __copy__(self) -> DifferentialInverseKinematicsSystem.CartesianVelocityLimitConstraint.Config: ...
            def __deepcopy__(self, arg: dict) -> DifferentialInverseKinematicsSystem.CartesianVelocityLimitConstraint.Config: ...
            @property
            def __fields__(self): ...
        def __init__(self, config: DifferentialInverseKinematicsSystem.CartesianVelocityLimitConstraint.Config) -> None: ...
        def GetConfig(self) -> DifferentialInverseKinematicsSystem.CartesianVelocityLimitConstraint.Config: ...
        def SetConfig(self, config: DifferentialInverseKinematicsSystem.CartesianVelocityLimitConstraint.Config) -> None: ...

    class CollisionConstraint(DifferentialInverseKinematicsSystem.Ingredient):
        class Config:
            influence_distance: float
            safety_distance: float
            def __init__(self, **kwargs) -> None: ...
            def __copy__(self) -> DifferentialInverseKinematicsSystem.CollisionConstraint.Config: ...
            def __deepcopy__(self, arg: dict) -> DifferentialInverseKinematicsSystem.CollisionConstraint.Config: ...
            @property
            def __fields__(self): ...
        def __init__(self, config: DifferentialInverseKinematicsSystem.CollisionConstraint.Config) -> None: ...
        def GetConfig(self) -> DifferentialInverseKinematicsSystem.CollisionConstraint.Config: ...
        def SetConfig(self, config: DifferentialInverseKinematicsSystem.CollisionConstraint.Config) -> None: ...
        def SetSelectDataForCollisionConstraintFunction(self, select_data_for_collision_constraint) -> None: ...

    class Ingredient:
        def __init__(self, *args, **kwargs) -> None: ...

    class JointCenteringCost(DifferentialInverseKinematicsSystem.Ingredient):
        class Config:
            cartesian_axis_masks: Incomplete
            posture_gain: float
            def __init__(self, **kwargs) -> None: ...
            def __copy__(self) -> DifferentialInverseKinematicsSystem.JointCenteringCost.Config: ...
            def __deepcopy__(self, arg: dict) -> DifferentialInverseKinematicsSystem.JointCenteringCost.Config: ...
            @property
            def __fields__(self): ...
        def __init__(self, config: DifferentialInverseKinematicsSystem.JointCenteringCost.Config) -> None: ...
        def GetConfig(self) -> DifferentialInverseKinematicsSystem.JointCenteringCost.Config: ...
        def SetConfig(self, config: DifferentialInverseKinematicsSystem.JointCenteringCost.Config) -> None: ...

    class JointVelocityLimitConstraint(DifferentialInverseKinematicsSystem.Ingredient):
        class Config:
            influence_margin: float
            min_margin: float
            def __init__(self, **kwargs) -> None: ...
            def __copy__(self) -> DifferentialInverseKinematicsSystem.JointVelocityLimitConstraint.Config: ...
            def __deepcopy__(self, arg: dict) -> DifferentialInverseKinematicsSystem.JointVelocityLimitConstraint.Config: ...
            @property
            def __fields__(self): ...
        def __init__(self, config: DifferentialInverseKinematicsSystem.JointVelocityLimitConstraint.Config, joint_limits: pydrake.planning.JointLimits) -> None: ...
        def GetConfig(self) -> DifferentialInverseKinematicsSystem.JointVelocityLimitConstraint.Config: ...
        def GetJointLimits(self) -> pydrake.planning.JointLimits: ...
        def SetConfig(self, config: DifferentialInverseKinematicsSystem.JointVelocityLimitConstraint.Config) -> None: ...
        def SetJointLimits(self, joint_limits: pydrake.planning.JointLimits) -> None: ...

    class LeastSquaresCost(DifferentialInverseKinematicsSystem.Ingredient):
        class Config:
            cartesian_axis_masks: Incomplete
            cartesian_qp_weight: float
            use_legacy_implementation: bool
            def __init__(self, **kwargs) -> None: ...
            def __copy__(self) -> DifferentialInverseKinematicsSystem.LeastSquaresCost.Config: ...
            def __deepcopy__(self, arg: dict) -> DifferentialInverseKinematicsSystem.LeastSquaresCost.Config: ...
            @property
            def __fields__(self): ...
        def __init__(self, config: DifferentialInverseKinematicsSystem.LeastSquaresCost.Config) -> None: ...
        def GetConfig(self) -> DifferentialInverseKinematicsSystem.LeastSquaresCost.Config: ...
        def SetConfig(self, config: DifferentialInverseKinematicsSystem.LeastSquaresCost.Config) -> None: ...

    class Recipe:
        def __init__(self) -> None: ...
        def AddIngredient(self, ingredient: object) -> None: ...
        def ingredient(self, i: int) -> DifferentialInverseKinematicsSystem.Ingredient: ...
        def num_ingredients(self) -> int: ...
    def __init__(self, recipe: object, task_frame: str, collision_checker: object, active_dof: pydrake.planning.DofMask, time_step: float, K_VX: float, Vd_TG_limit: pydrake.multibody.math.SpatialVelocity) -> None: ...
    def K_VX(self) -> float: ...
    def Vd_TG_limit(self) -> pydrake.multibody.math.SpatialVelocity: ...
    def active_dof(self) -> pydrake.planning.DofMask: ...
    def collision_checker(self) -> pydrake.planning.CollisionChecker: ...
    def get_input_port_desired_cartesian_poses(self) -> pydrake.systems.framework.InputPort: ...
    def get_input_port_desired_cartesian_velocities(self) -> pydrake.systems.framework.InputPort: ...
    def get_input_port_nominal_posture(self) -> pydrake.systems.framework.InputPort: ...
    def get_input_port_position(self) -> pydrake.systems.framework.InputPort: ...
    def get_output_port_commanded_velocity(self) -> pydrake.systems.framework.OutputPort: ...
    def plant(self) -> pydrake.multibody.plant.MultibodyPlant: ...
    def recipe(self) -> DifferentialInverseKinematicsSystem.Recipe: ...
    def task_frame(self) -> pydrake.multibody.tree.Frame: ...
    def time_step(self) -> float: ...

class DistanceConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, geometry_pair: tuple[pydrake.geometry.GeometryId, pydrake.geometry.GeometryId], plant_context: pydrake.systems.framework.Context, distance_lower: float, distance_upper: float) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, geometry_pair: tuple[pydrake.geometry.GeometryId, pydrake.geometry.GeometryId], plant_context: pydrake.systems.framework.Context_TAutoDiffXdU, distance_lower: float, distance_upper: float) -> None: ...

class GazeTargetConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frameA: pydrake.multibody.tree.Frame, p_AS, n_A, frameB: pydrake.multibody.tree.Frame, p_BT, cone_half_angle: float, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frameA: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_AS, n_A, frameB: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_BT, cone_half_angle: float, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class GlobalInverseKinematics:
    class Options:
        approach: Incomplete
        interval_binning: Incomplete
        linear_constraint_only: bool
        num_intervals_per_half_axis: Incomplete
        def __init__(self) -> None: ...

    class Polytope3D:
        A: Incomplete
        b: Incomplete
        def __init__(self, A, b) -> None: ...
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, options: GlobalInverseKinematics.Options = ...) -> None: ...
    def AddJointLimitConstraint(self, body_index: pydrake.multibody.tree.BodyIndex, joint_lower_bound: float, joint_upper_bound: float, linear_constraint_approximation: bool = ...) -> None: ...
    def AddPostureCost(self, q_desired, body_position_cost, body_orientation_cost) -> None: ...
    def AddWorldOrientationConstraint(self, body_index: pydrake.multibody.tree.BodyIndex, desired_orientation: pydrake.common.eigen_geometry.Quaternion, angle_tol: float) -> pydrake.solvers.BindingTLinearConstraintU: ...
    def AddWorldPositionConstraint(self, body_index: pydrake.multibody.tree.BodyIndex, p_BQ, box_lb_F, box_ub_F, X_WF: pydrake.math.RigidTransform = ...) -> pydrake.solvers.BindingTLinearConstraintU: ...
    def AddWorldRelativePositionConstraint(self, body_index_B: pydrake.multibody.tree.BodyIndex, p_BQ, body_index_A: pydrake.multibody.tree.BodyIndex, p_AP, box_lb_F, box_ub_F, X_WF: pydrake.math.RigidTransform = ...) -> pydrake.solvers.BindingTLinearConstraintU: ...
    def BodyPointInOneOfRegions(self, *args, **kwargs): ...
    def BodySphereInOneOfPolytopes(self, *args, **kwargs): ...
    def ReconstructGeneralizedPositionSolution(self, *args, **kwargs): ...
    def SetInitialGuess(self, q) -> None: ...
    def body_position(self, *args, **kwargs): ...
    def body_rotation_matrix(self, *args, **kwargs): ...
    def get_mutable_prog(self) -> pydrake.solvers.MathematicalProgram: ...
    def prog(self) -> pydrake.solvers.MathematicalProgram: ...

class InverseKinematics:
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, with_joint_limits: bool = ...) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, plant_context: pydrake.systems.framework.Context, with_joint_limits: bool = ...) -> None: ...
    def AddAngleBetweenVectorsConstraint(self, frameA: pydrake.multibody.tree.Frame, na_A, frameB: pydrake.multibody.tree.Frame, nb_B, angle_lower: float, angle_upper: float) -> pydrake.solvers.BindingTConstraintU: ...
    def AddAngleBetweenVectorsCost(self, frameA: pydrake.multibody.tree.Frame, na_A, frameB: pydrake.multibody.tree.Frame, nb_B, c: float) -> pydrake.solvers.BindingTCostU: ...
    def AddDistanceConstraint(self, geometry_pair: tuple[pydrake.geometry.GeometryId, pydrake.geometry.GeometryId], distance_lower: float, distance_upper: float) -> pydrake.solvers.BindingTConstraintU: ...
    def AddGazeTargetConstraint(self, frameA: pydrake.multibody.tree.Frame, p_AS, n_A, frameB: pydrake.multibody.tree.Frame, p_BT, cone_half_angle: float) -> pydrake.solvers.BindingTConstraintU: ...
    def AddMinimumDistanceLowerBoundConstraint(self, bound: float, influence_distance_offset: float = ...) -> pydrake.solvers.BindingTConstraintU: ...
    def AddMinimumDistanceUpperBoundConstraint(self, bound: float, influence_distance_offset: float) -> pydrake.solvers.BindingTConstraintU: ...
    def AddOrientationConstraint(self, frameAbar: pydrake.multibody.tree.Frame, R_AbarA: pydrake.math.RotationMatrix, frameBbar: pydrake.multibody.tree.Frame, R_BbarB: pydrake.math.RotationMatrix, theta_bound: float) -> pydrake.solvers.BindingTConstraintU: ...
    def AddOrientationCost(self, frameAbar: pydrake.multibody.tree.Frame, R_AbarA: pydrake.math.RotationMatrix, frameBbar: pydrake.multibody.tree.Frame, R_BbarB: pydrake.math.RotationMatrix, c: float) -> pydrake.solvers.BindingTCostU: ...
    def AddPointToLineDistanceConstraint(self, frame_point: pydrake.multibody.tree.Frame, p_B1P, frame_line: pydrake.multibody.tree.Frame, p_B2Q, n_B2, distance_lower: float, distance_upper: float) -> pydrake.solvers.BindingTConstraintU: ...
    def AddPointToPointDistanceConstraint(self, frame1: pydrake.multibody.tree.Frame, p_B1P1, frame2: pydrake.multibody.tree.Frame, p_B2P2, distance_lower: float, distance_upper: float) -> pydrake.solvers.BindingTConstraintU: ...
    def AddPolyhedronConstraint(self, frameF: pydrake.multibody.tree.Frame, frameG: pydrake.multibody.tree.Frame, p_GP, A, b) -> pydrake.solvers.BindingTConstraintU: ...
    @overload
    def AddPositionConstraint(self, frameB: pydrake.multibody.tree.Frame, p_BQ, frameA: pydrake.multibody.tree.Frame, p_AQ_lower, p_AQ_upper) -> pydrake.solvers.BindingTConstraintU: ...
    @overload
    def AddPositionConstraint(self, frameB: pydrake.multibody.tree.Frame, p_BQ, frameAbar: pydrake.multibody.tree.Frame, X_AbarA: pydrake.math.RigidTransform | None, p_AQ_lower, p_AQ_upper) -> pydrake.solvers.BindingTConstraintU: ...
    def AddPositionCost(self, frameA: pydrake.multibody.tree.Frame, p_AP, frameB: pydrake.multibody.tree.Frame, p_BQ, C) -> pydrake.solvers.BindingTCostU: ...
    def context(self) -> pydrake.systems.framework.Context: ...
    def get_mutable_context(self) -> pydrake.systems.framework.Context: ...
    def get_mutable_prog(self) -> pydrake.solvers.MathematicalProgram: ...
    def prog(self) -> pydrake.solvers.MathematicalProgram: ...
    def q(self, *args, **kwargs): ...

class MinimumDistanceLowerBoundConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, bound: float, plant_context: pydrake.systems.framework.Context, penalty_function: collections.abc.Callable[[float, bool], tuple] | None = ..., influence_distance_offset: float = ...) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, bound: float, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU, penalty_function: collections.abc.Callable[[float, bool], tuple] | None = ..., influence_distance_offset: float = ...) -> None: ...
    @overload
    def __init__(self, collision_checker: pydrake.planning.CollisionChecker, bound: float, collision_checker_context: pydrake.planning.CollisionCheckerContext, penalty_function: collections.abc.Callable[[float, bool], tuple] | None = ..., influence_distance_offset: float = ...) -> None: ...
    def distance_bound(self) -> float: ...
    def influence_distance(self) -> float: ...

class MinimumDistanceUpperBoundConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, bound: float, plant_context: pydrake.systems.framework.Context, influence_distance_offset: float, penalty_function: collections.abc.Callable[[float, bool], tuple] | None = ...) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, bound: float, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU, influence_distance_offset: float, penalty_function: collections.abc.Callable[[float, bool], tuple] | None = ...) -> None: ...
    @overload
    def __init__(self, collision_checker: pydrake.planning.CollisionChecker, bound: float, collision_checker_context: pydrake.planning.CollisionCheckerContext, influence_distance_offset: float, penalty_function: collections.abc.Callable[[float, bool], tuple] | None = ...) -> None: ...
    def distance_bound(self) -> float: ...
    def influence_distance(self) -> float: ...

class OrientationConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frameAbar: pydrake.multibody.tree.Frame, R_AbarA: pydrake.math.RotationMatrix, frameBbar: pydrake.multibody.tree.Frame, R_BbarB: pydrake.math.RotationMatrix, theta_bound: float, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frameAbar: pydrake.multibody.tree.Frame_TAutoDiffXdU, R_AbarA: pydrake.math.RotationMatrix, frameBbar: pydrake.multibody.tree.Frame_TAutoDiffXdU, R_BbarB: pydrake.math.RotationMatrix, theta_bound: float, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class OrientationCost(pydrake.solvers.Cost):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frameAbar: pydrake.multibody.tree.Frame, R_AbarA: pydrake.math.RotationMatrix, frameBbar: pydrake.multibody.tree.Frame, R_BbarB: pydrake.math.RotationMatrix, c: float, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frameAbar: pydrake.multibody.tree.Frame_TAutoDiffXdU, R_AbarA: pydrake.math.RotationMatrix, frameBbar: pydrake.multibody.tree.Frame_TAutoDiffXdU, R_BbarB: pydrake.math.RotationMatrix, c: float, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class PointToLineDistanceConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frame_point: pydrake.multibody.tree.Frame, p_B1P, frame_line: pydrake.multibody.tree.Frame, p_B2Q, n_B2, distance_lower: float, distance_upper: float, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frame_point: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_B1P, frame_line: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_B2Q, n_B2, distance_lower: float, distance_upper: float, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class PointToPointDistanceConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frame1: pydrake.multibody.tree.Frame, p_B1P1, frame2: pydrake.multibody.tree.Frame, p_B2P2, distance_lower: float, distance_upper: float, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frame1: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_B1P1, frame2: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_B2P2, distance_lower: float, distance_upper: float, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class PolyhedronConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frameF: pydrake.multibody.tree.Frame, frameG: pydrake.multibody.tree.Frame, p_GP, A, b, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frameF: pydrake.multibody.tree.Frame_TAutoDiffXdU, frameG: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_GP, A, b, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class PositionConstraint(pydrake.solvers.Constraint):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frameA: pydrake.multibody.tree.Frame, p_AQ_lower, p_AQ_upper, frameB: pydrake.multibody.tree.Frame, p_BQ, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frameAbar: pydrake.multibody.tree.Frame, X_AbarA: pydrake.math.RigidTransform | None, p_AQ_lower, p_AQ_upper, frameB: pydrake.multibody.tree.Frame, p_BQ, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frameA: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_AQ_lower, p_AQ_upper, frameB: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_BQ, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frameAbar: pydrake.multibody.tree.Frame_TAutoDiffXdU, X_AbarA: pydrake.math.RigidTransform | None, p_AQ_lower, p_AQ_upper, frameB: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_BQ, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...
    def UpdateLowerBound(self, new_lb) -> None: ...
    def UpdateUpperBound(self, new_ub) -> None: ...
    def set_bounds(self, new_lb, new_ub) -> None: ...

class PositionCost(pydrake.solvers.Cost):
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant, frameA: pydrake.multibody.tree.Frame, p_AP, frameB: pydrake.multibody.tree.Frame, p_BQ, C, plant_context: pydrake.systems.framework.Context) -> None: ...
    @overload
    def __init__(self, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, frameA: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_AP, frameB: pydrake.multibody.tree.Frame_TAutoDiffXdU, p_BQ, C, plant_context: pydrake.systems.framework.Context_TAutoDiffXdU) -> None: ...

class UnitQuaternionConstraint(pydrake.solvers.Constraint):
    def __init__(self) -> None: ...



import collections.abc
import nanobind
import pydrake.geometry
import pydrake.multibody.plant
import pydrake.systems.framework
from _typeshed import Incomplete
from pydrake.common.cpp_template import ContactVisualizer_ as ContactVisualizer_, JointSliders_ as JointSliders_
from typing import ClassVar

class ContactVisualizer(pydrake.systems.framework.LeafSystem):
    AddToBuilder: ClassVar[nanobind.nb_func] = ...
    def __init__(self, meshcat: pydrake.geometry.Meshcat, params: ContactVisualizerParams = ...) -> None: ...
    def Delete(self) -> None: ...
    def contact_results_input_port(self) -> pydrake.systems.framework.InputPort: ...
    def query_object_input_port(self) -> pydrake.systems.framework.InputPort: ...

class ContactVisualizerParams:
    color: pydrake.geometry.Rgba
    delete_on_initialization_event: bool
    force_threshold: float
    hydro_force_color: pydrake.geometry.Rgba
    hydro_moment_color: pydrake.geometry.Rgba
    moment_threshold: float
    newton_meters_per_meter: float
    newtons_per_meter: float
    prefix: str
    publish_period: float
    radius: float
    def __init__(self, **kwargs) -> None: ...
    def __copy__(self) -> ContactVisualizerParams: ...
    def __deepcopy__(self, arg: dict) -> ContactVisualizerParams: ...
    @property
    def __fields__(self): ...

class ContactVisualizer_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    AddToBuilder: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, meshcat: pydrake.geometry.Meshcat, params: ContactVisualizerParams = ...) -> None: ...
    def Delete(self) -> None: ...
    def contact_results_input_port(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def query_object_input_port(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...

class JointSliders(pydrake.systems.framework.LeafSystem):
    def __init__(self, meshcat: pydrake.geometry.Meshcat, plant: pydrake.multibody.plant.MultibodyPlant, initial_value=..., lower_limit=..., upper_limit=..., step=..., decrement_keycodes: collections.abc.Sequence[str] = ..., increment_keycodes: collections.abc.Sequence[str] = ...) -> None: ...
    def Delete(self) -> None: ...
    def Run(self, *args, **kwargs): ...
    def SetPositions(self, q) -> None: ...

class JointSliders_𝓣AutoDiffXd𝓤(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, meshcat: pydrake.geometry.Meshcat, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, initial_value=..., lower_limit=..., upper_limit=..., step=..., decrement_keycodes: collections.abc.Sequence[str] = ..., increment_keycodes: collections.abc.Sequence[str] = ...) -> None: ...
    def Delete(self) -> None: ...
    def Run(self, *args, **kwargs): ...
    def SetPositions(self, q) -> None: ...

class _HydroelasticContactVisualizer:
    def __init__(self, meshcat: pydrake.geometry.Meshcat, params: ContactVisualizerParams) -> None: ...
    def Delete(self) -> None: ...
    def Update(self, time: float, items: collections.abc.Sequence[_HydroelasticContactVisualizerItem]) -> None: ...

class _HydroelasticContactVisualizerItem:
    body_A: Incomplete
    body_B: Incomplete
    centroid_W: Incomplete
    faces: Incomplete
    force_C_W: Incomplete
    moment_C_W: Incomplete
    p_WV: Incomplete
    pressure: Incomplete
    def __init__(self, body_A: str, body_B: str, centroid_W, force_C_W, moment_C_W, p_WV, faces, pressure) -> None: ...

class _PointContactVisualizer:
    def __init__(self, meshcat: pydrake.geometry.Meshcat, params: ContactVisualizerParams) -> None: ...
    def Update(self, time: float, items: collections.abc.Sequence[_PointContactVisualizerItem]) -> None: ...

class _PointContactVisualizerItem:
    body_A: Incomplete
    body_B: Incomplete
    contact_force: Incomplete
    contact_point: Incomplete
    def __init__(self, body_A: str, body_B: str, contact_force, contact_point) -> None: ...

class _TemporaryName_N5drake9multibody7meshcat12JointSlidersINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, meshcat: pydrake.geometry.Meshcat, plant: pydrake.multibody.plant.MultibodyPlant_TAutoDiffXdU, initial_value=..., lower_limit=..., upper_limit=..., step=..., decrement_keycodes: collections.abc.Sequence[str] = ..., increment_keycodes: collections.abc.Sequence[str] = ...) -> None: ...
    def Delete(self) -> None: ...
    def Run(self, *args, **kwargs): ...
    def SetPositions(self, q) -> None: ...

class _TemporaryName_N5drake9multibody7meshcat17ContactVisualizerINS_2ad8AutoDiffEEE(pydrake.systems.framework.LeafSystem_TAutoDiffXdU):
    AddToBuilder: ClassVar[nanobind.nb_func] = ...
    _original_name: ClassVar[str] = ...
    _original_qualname: ClassVar[str] = ...
    def __init__(self, meshcat: pydrake.geometry.Meshcat, params: ContactVisualizerParams = ...) -> None: ...
    def Delete(self) -> None: ...
    def contact_results_input_port(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...
    def query_object_input_port(self) -> pydrake.systems.framework.InputPort_TAutoDiffXdU: ...



"""LCM type definitions
This file automatically generated by lcm.
DO NOT MODIFY BY HAND!!!!
"""


from io import BytesIO
import struct

class lcmt_hydroelastic_quadrature_per_point_data_for_viz(object):

    __slots__ = ["p_WQ", "vt_BqAq_W", "traction_Aq_W"]

    __typenames__ = ["double", "double", "double"]

    __dimensions__ = [[3], [3], [3]]

    def __init__(self):
        self.p_WQ = [ 0.0 for dim0 in range(3) ]
        """
        The quadrature point Q, as an offset vector in the world frame W, at which
        the traction and slip velocities are evaluated.
        LCM Type: double[3]
        """

        self.vt_BqAq_W = [ 0.0 for dim0 in range(3) ]
        """
        Denoting Point Aq as the point of Body A coincident with Q and Point Bq as
        the point of Body B coincident with Q, calculates vr (the velocity
        of Bq relative to Aq) and then calculates the component perpendicular to
        the unit surface normal n̂ as vt = vr - (vr⋅n̂)n̂.
        The resulting vector vt is expressed in the world frame W.
        LCM Type: double[3]
        """

        self.traction_Aq_W = [ 0.0 for dim0 in range(3) ]
        """
        The traction vector, expressed in the world frame and with units of Pa,
        applied to Body A at Point Q (i.e., Frame A is shifted to Aq).
        LCM Type: double[3]
        """


    def encode(self):
        buf = BytesIO()
        buf.write(lcmt_hydroelastic_quadrature_per_point_data_for_viz._get_packed_fingerprint())
        self._encode_one(buf)
        return buf.getvalue()

    def _encode_one(self, buf):
        buf.write(struct.pack('>3d', *self.p_WQ[:3]))
        buf.write(struct.pack('>3d', *self.vt_BqAq_W[:3]))
        buf.write(struct.pack('>3d', *self.traction_Aq_W[:3]))

    @staticmethod
    def decode(data: bytes):
        if hasattr(data, 'read'):
            buf = data
        else:
            buf = BytesIO(data)
        if buf.read(8) != lcmt_hydroelastic_quadrature_per_point_data_for_viz._get_packed_fingerprint():
            raise ValueError("Decode error")
        return lcmt_hydroelastic_quadrature_per_point_data_for_viz._decode_one(buf)

    @staticmethod
    def _decode_one(buf):
        self = lcmt_hydroelastic_quadrature_per_point_data_for_viz()
        self.p_WQ = struct.unpack('>3d', buf.read(24))
        self.vt_BqAq_W = struct.unpack('>3d', buf.read(24))
        self.traction_Aq_W = struct.unpack('>3d', buf.read(24))
        return self

    @staticmethod
    def _get_hash_recursive(parents):
        if lcmt_hydroelastic_quadrature_per_point_data_for_viz in parents: return 0
        tmphash = (0xc093c3933c1ec1d9) & 0xffffffffffffffff
        tmphash  = (((tmphash<<1)&0xffffffffffffffff) + (tmphash>>63)) & 0xffffffffffffffff
        return tmphash
    _packed_fingerprint = None

    @staticmethod
    def _get_packed_fingerprint():
        if lcmt_hydroelastic_quadrature_per_point_data_for_viz._packed_fingerprint is None:
            lcmt_hydroelastic_quadrature_per_point_data_for_viz._packed_fingerprint = struct.pack(">Q", lcmt_hydroelastic_quadrature_per_point_data_for_viz._get_hash_recursive([]))
        return lcmt_hydroelastic_quadrature_per_point_data_for_viz._packed_fingerprint

    def get_hash(self):
        """Get the LCM hash of the struct"""
        return struct.unpack(">Q", lcmt_hydroelastic_quadrature_per_point_data_for_viz._get_packed_fingerprint())[0]




import enum
import nanobind
import numpy
import pydrake.common
import pydrake.systems.framework
import pydrake.systems.sensors
from typing import Callable, ClassVar, overload

Concatenate: nanobind.nb_func

class BaseField(enum.IntEnum):
    __new__: ClassVar[Callable] = ...
    _generate_next_value_: ClassVar[Callable] = ...
    _hashable_values_: ClassVar[list] = ...
    _member_map_: ClassVar[dict] = ...
    _member_names_: ClassVar[list] = ...
    _member_type_: ClassVar[type[int]] = ...
    _unhashable_values_: ClassVar[list] = ...
    _unhashable_values_map_: ClassVar[dict] = ...
    _use_args_: ClassVar[bool] = ...
    _value2member_map_: ClassVar[dict] = ...
    kNone: ClassVar[BaseField] = ...
    kNormals: ClassVar[BaseField] = ...
    kRGBs: ClassVar[BaseField] = ...
    kXYZs: ClassVar[BaseField] = ...
    __nb_enum__: ClassVar[PyCapsule] = ...
    def __format__(self, *args, **kwargs) -> str: ...

class DepthImageToPointCloud(pydrake.systems.framework.LeafSystem):
    def __init__(self, camera_info: pydrake.systems.sensors.CameraInfo, pixel_type: pydrake.systems.sensors.PixelType = ..., scale: float = ..., fields: int = ...) -> None: ...
    def camera_pose_input_port(self) -> pydrake.systems.framework.InputPort: ...
    def color_image_input_port(self) -> pydrake.systems.framework.InputPort: ...
    def depth_image_input_port(self) -> pydrake.systems.framework.InputPort: ...
    def point_cloud_output_port(self) -> pydrake.systems.framework.OutputPort: ...

class Fields:
    def __init__(self, base_fields: int) -> None: ...
    def base_fields(self) -> int: ...
    def has_base_fields(self) -> bool: ...
    def __and__(self, arg: Fields) -> Fields: ...
    def __eq__(self, arg: Fields) -> bool: ...
    def __ne__(self, arg: Fields) -> bool: ...
    def __or__(self, arg: Fields) -> Fields: ...

class PointCloud:
    C: ClassVar[type[numpy.uint8]] = ...
    D: ClassVar[type[numpy.float32]] = ...
    IsDefaultValue: ClassVar[nanobind.nb_func] = ...
    IsInvalidValue: ClassVar[nanobind.nb_func] = ...
    T: ClassVar[type[numpy.float32]] = ...
    kDefaultValue: ClassVar[float] = ...
    @overload
    def __init__(self, new_size: int = ..., fields: Fields = ...) -> None: ...
    @overload
    def __init__(self, other: PointCloud) -> None: ...
    def Crop(self, lower_xyz, upper_xyz) -> PointCloud: ...
    def EstimateNormals(self, radius: float, num_closest: int, parallelize: pydrake.common.Parallelism = ...) -> bool: ...
    def FlipNormalsTowardPoint(self, p_CP) -> None: ...
    def SetFields(self, new_fields: Fields, skip_initialize: bool = ...) -> None: ...
    def SetFrom(self, other: PointCloud) -> None: ...
    def VoxelizedDownSample(self, voxel_size: float, parallelize: pydrake.common.Parallelism = ...) -> PointCloud: ...
    def fields(self) -> Fields: ...
    def has_normals(self) -> bool: ...
    def has_rgbs(self) -> bool: ...
    def has_xyzs(self) -> bool: ...
    def mutable_normal(self, *args, **kwargs): ...
    def mutable_normals(self, *args, **kwargs): ...
    def mutable_rgb(self, *args, **kwargs): ...
    def mutable_rgbs(self, *args, **kwargs): ...
    def mutable_xyz(self, *args, **kwargs): ...
    def mutable_xyzs(self, *args, **kwargs): ...
    def normal(self, *args, **kwargs): ...
    def normals(self, *args, **kwargs): ...
    def resize(self, new_size: int) -> None: ...
    def rgb(self, *args, **kwargs): ...
    def rgbs(self, *args, **kwargs): ...
    def size(self) -> int: ...
    def xyz(self, *args, **kwargs): ...
    def xyzs(self, *args, **kwargs): ...
    def __copy__(self) -> PointCloud: ...
    def __deepcopy__(self, arg: dict) -> PointCloud: ...

class PointCloudToLcm(pydrake.systems.framework.LeafSystem):
    def __init__(self, frame_name: str = ...) -> None: ...
